NAME = "vancouver_watching"

ICON = "🌈"

DESCRIPTION = f"{ICON} Vancouver Watching with AI."

VERSION = "4.34.1"

REPO_NAME = "vancouver-watching"

MARQUEE = "https://github.com/kamangir/assets/blob/main/vanwatch/QGIS.png?raw=true"

ALIAS = "vanwatch"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
